API - 语义理解问答 — chat 1.0.5 documentation

# API - 语义理解问答

qa

NLU based on Natural Language Processing and Graph Database. 基于自然语言处理与图形数据库的自然语言理解。

Available functions: - All classes and functions: 所有类和函数

`Robot`([password]) | NLU Robot.

## 语义理解机器人

`chat.qa.` `Robot`(password='train')

  NLU Robot. 自然语言理解机器人。

  Public attributes: - graph: The connection of graph database. 图形数据库连接。 - pattern: The pattern for NLU tool: ‘semantic’ or ‘vec’. 语义标签或词向量模式。 - memory: The context memory of robot. 机器人对话上下文记忆。